@@ -51,7 +51,8 @@ BOOTPROTO=static
 ONBOOT=yes
 IPADDR=127.0.0.1
 NETMASK=255.255.255.255
-BROADCAST=0.0.0.0" > $IFCFG || error "Can't write to file $IFCFG" $VZ_FS_NO_DISK_SPACE
+BROADCAST=0.0.0.0
+ARPCHECK=\"no\"" > $IFCFG || error "Can't write to file $IFCFG" $VZ_FS_NO_DISK_SPACE
 
 	# Set /etc/sysconfig/network
 	put_param $NETFILE NETWORKING yes
@@ -59,7 +60,6 @@ BROADCAST=0.0.0.0" > $IFCFG || error "Can't write to file $IFCFG" $VZ_FS_NO_DISK
 	put_param $NETFILE GATEWAYDEV ${VENET_DEV}
 	# Remove old (obsoleted) fake route
 	del_param $NETFILE GATEWAY
-	[ -f "${IFCFG_DIR}/route-venet0" ] && rm -f ${IFCFG_DIR}/route-venet0
 	# setup ipv6
 	setup6_network
 
@@ -87,13 +87,14 @@ function setup6_network()
 function create_config()
 {
 	local ip=$1
-	local ifnum=$2
+	local netmask=$2
+	local ifnum=$3
 	local file=${IFCFG_DIR}/bak/${VENET_DEV_CFG}:${ifnum}
 
 	echo "DEVICE=${VENET_DEV}:${ifnum}
 ONBOOT=yes
 IPADDR=${ip}
-NETMASK=255.255.255.255" > $file ||
+NETMASK=${netmask}" > $file ||
 	error "Can't write to file $file" ${VZ_FS_NO_DISK_SPACE}
 }
 
@@ -102,8 +103,12 @@ function add_ip6()
 	[ "${IPV6}" != "yes" ] && return
 	if ! grep -qw "$1" ${IFCFG} 2>/dev/null; then
 		setup6_network
-		add_param ${IFCFG} IPV6ADDR_SECONDARIES "$1/128"
-		ifconfig ${VENET_DEV} add "$1/128"
+		add_param ${IFCFG} IPV6ADDR_SECONDARIES "$1/$2"
+		if have_ifconfig; then
+			ifconfig ${VENET_DEV} add "$1/$2"
+		else
+			ip a a $1/$2 dev ${VENET_DEV}
+		fi
 	fi
 }
 
@@ -122,8 +127,8 @@ function get_aliasid_by_ip()
 	local idlist
 
 	cd ${IFCFG_DIR} || return 1
-	IFNUM=`grep -l "IPADDR=${ip}$" ${VENET_DEV_CFG}:* | head -n 1 |
-		sed -e 's/.*:\([0-9]*\)$/\1/'`
+	IFNUM=`grep -l "IPADDR=${ip}$" ${VENET_DEV_CFG}:* 2>/dev/null | \
+		head -n 1 | sed -e 's/.*:\([0-9]*\)$/\1/'`
 }
 
 function get_free_aliasid()
@@ -161,9 +166,24 @@ function move_configs()
 	rm -rf ${IFCFG_DIR}/bak
 }
 
+function check_running()
+{
+	if have_ifconfig; then
+		if ifconfig ${VENET_DEV} | grep -qFw RUNNING 2>/dev/null; then
+			return 1
+		fi
+	else
+		if ip l l ${VENET_DEV} | grep -qFw UP 2>/dev/null; then
+			return 1
+		fi
+	fi
+
+	return 0
+}
+
 function add_ip()
 {
-	local ip
+	local ipm
 	local new_ips
 	local if_restart=
 
@@ -185,25 +205,27 @@ function add_ip()
 	new_ips="${IP_ADDR}"
 	if [ "x${IPDELALL}" = "xyes" ]; then
 		new_ips=
-		for ip in ${IP_ADDR}; do
-			get_aliasid_by_ip "${ip}"
+		for ipm in ${IP_ADDR}; do
+			ip_conv $ipm
+			get_aliasid_by_ip "${_IP}"
 			if [ -n "${IFNUM}" ]; then
 				# ip already exists just create it in bak
-				create_config "${ip}" "${IFNUM}"
+				create_config "${_IP}" "${_NETMASK}" "${IFNUM}"
 			else
-				new_ips="${new_ips} ${ip}"
+				new_ips="${new_ips} ${ipm}"
 			fi
 		done
 	fi
-	for ip in ${new_ips}; do
-		if [ "${ip#*:}" = "${ip}" ]; then
+	for ipm in ${new_ips}; do
+		ip_conv $ipm
+		if [ -z "$_IPV6ADDR" ]; then
 			get_free_aliasid
-			create_config "${ip}" "${IFNUM}"
+			create_config "${_IP}" "${_NETMASK}" "${IFNUM}"
 		else
 			if [ "x${IPDELALL}" = "xyes" ]; then
 				del_param ${IFCFG} IPV6ADDR_SECONDARIES ""
 			fi
-			add_ip6 "${ip}"
+			add_ip6 "${_IP}" "${_MASK}"
 		fi
 	done
 	move_configs
@@ -211,7 +233,8 @@ function add_ip()
 		# synchronyze config files & interfaces
 		if [ "${NETWORKRESTART}" = "yes" ]; then
 			/etc/init.d/network restart
-		elif ! ifconfig ${VENET_DEV}|grep -q RUNNING 2>/dev/null; then
+		elif check_running; then
+			# check_running return 0; so not running; restart
 			/etc/init.d/network restart
 		elif [ -n "${if_restart}" ]; then
 			ifup ${VENET_DEV}
