@@ -33,6 +33,7 @@
 struct env_param {
 	envid_t veid;
 	unsigned long long ipt_mask;
+	unsigned long nf_mask;	/* netfilter */
 
 	/*
 	 * features_known is the set of features that are present
@@ -147,6 +148,7 @@ struct vzctl_snapshot_param {
 	char *desc;
 #define SNAPSHOT_SKIP_SUSPEND	1 << 1
 #define SNAPSHOT_SKIP_CONFIG	1 << 2
+#define SNAPSHOT_SKIP_RESUME	1 << 3
 	int flags;
 	char *target;	/* snapshot mount point */
 };
