@@ -62,6 +62,7 @@ static vps_config config[] = {
 {"VERBOSE",	NULL, PARAM_VERBOSE},
 
 {"IPTABLES",	NULL, PARAM_IPTABLES},
+{"NETFILTER",	NULL, PARAM_NETFILTER},
 /*	UB	*/
 {"KMEMSIZE",	NULL, PARAM_KMEMSIZE},
 {"LOCKEDPAGES",	NULL, PARAM_LOCKEDPAGES},
@@ -165,6 +166,7 @@ static vps_config config[] = {
 {"CONFIG_CUSTOMIZED",	NULL, PARAM_IGNORED},
 {"VE_STOP_MODE",	NULL, PARAM_IGNORED},
 {"SKIP_SYSCTL_SETUP",	NULL, PARAM_IGNORED},
+{"SKIP_ARPDETECT",	NULL, PARAM_IGNORED},
 
 {NULL,		NULL, -1}
 };
@@ -584,26 +586,6 @@ static int store_io(vps_param *old_p, vps_param *vps_p,
 }
 
 /******************** Iptables *************************/
-static int parse_iptables(env_param_t *env, char *val)
-{
-	char *token;
-	struct iptables_s *ipt;
-	int ret = 0;
-
-	for_each_strtok(token, val, "\t ,") {
-		ipt = find_ipt(token);
-		if (!ipt) {
-			logger(-1, 0, "Warning: Unknown iptable module: %s,"
-				" skipped", token);
-			ret = ERR_INVAL_SKIP;
-			continue;
-		}
-		env->ipt_mask |= ipt->mask;
-	}
-
-	return ret;
-}
-
 static void store_iptables(unsigned long long ipt_mask, vps_config *conf,
 	list_head_t *conf_h)
 {
@@ -627,6 +609,12 @@ static int store_env(vps_param *old_p, vps_param *vps_p, vps_config *conf,
 			break;
 		store_iptables(env->ipt_mask, conf, conf_h);
 		break;
+	case PARAM_NETFILTER:
+		if (!env->nf_mask)
+			break;
+		conf_store_str(conf_h, conf->name,
+				netfilter_mask2str(env->nf_mask));
+		break;
 	case PARAM_FEATURES:
 		if (!env->features_known)
 			break;
@@ -1084,7 +1072,7 @@ static int store_tmpl(vps_param *old_p, vps_param *vps_p, vps_config *conf,
 }
 
 /***********************Quota***************************/
-static int parse_dq(unsigned long **param, const char *val, int sfx)
+static int parse_dq(unsigned long **param, const char *val, int divisor)
 {
 	int ret;
 	unsigned long *tmp;
@@ -1092,7 +1080,7 @@ static int parse_dq(unsigned long **param, const char *val, int sfx)
 	tmp = malloc(sizeof(unsigned long) * 2);
 	if (tmp == NULL)
 		return ERR_NOMEM;
-	ret = parse_twoul_sfx(val, tmp, sfx ? 1024 : 0, 0);
+	ret = parse_twoul_sfx(val, tmp, divisor, 0);
 	if (ret && ret != ERR_LONG_TRUNC) {
 		free(tmp);
 		return ret;
@@ -1662,17 +1650,17 @@ static int parse_netif_str(envid_t veid, const char *str, veth_dev *dev)
 		if (!strncmp("ifname=", p, 7)) {
 			p += 7;
 			len = next - p;
-			if (len > IFNAMSIZE)
+			if (len + 1 > IFNAMSIZE)
 				return ERR_INVAL;
 			if (dev->dev_name_ve[0] == '\0')
-				strncpy(dev->dev_name_ve, p, len);
+				snprintf(dev->dev_name_ve, len + 1, "%s", p);
 		} else if (!strncmp("host_ifname=", p, 12)) {
 			p += 12;
 			len = next - p;
-			if (len > IFNAMSIZE)
+			if (len + 1 > IFNAMSIZE)
 				return ERR_INVAL;
 			if (dev->dev_name[0] == '\0')
-				strncpy(dev->dev_name, p, len);
+				snprintf(dev->dev_name, len + 1, "%s", p);
 		} else if (!strncmp("mac=", p, 4)) {
 			p += 4;
 			len = next - p;
@@ -1710,10 +1698,10 @@ static int parse_netif_str(envid_t veid, const char *str, veth_dev *dev)
 		} else if (!strncmp("bridge=", p, 7)) {
 			p += 7;
 			len = next - p;
-			if (len > IFNAMSIZE)
+			if (len + 1 > IFNAMSIZE)
 				return ERR_INVAL;
 			if (dev->dev_bridge[0] == '\0')
-				strncpy(dev->dev_bridge, p, len);
+				snprintf(dev->dev_bridge, len + 1, "%s", p);
 		}
 		p = ++next;
 	} while (p < ep);
@@ -2119,9 +2107,17 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 		*vps_p->log.verbose = int_id;
 		break;
 	case PARAM_IPTABLES:
+		/* TODO:
+		 * vzctl  4.8: warn the option is obsoleted by netfilter
+		 * vzctl  4.9: ignore from command line with a warning
+		 * vzctl 4.10: ignore from configuration file?
+		 * vzctl 4.11: remove?
+		 */
 		ret = parse_iptables(&vps_p->res.env, val);
 		break;
-
+	case PARAM_NETFILTER:
+		ret = parse_netfilter(&vps_p->res.env, val);
+		break;
 	case PARAM_LOCAL_UID:
 		conf_parse_ulong(&vps_p->res.misc.local_uid, val);
 		break;
@@ -2211,13 +2207,13 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 	case PARAM_DISKSPACE:
 		if (vps_p->res.dq.diskspace != NULL)
 			return ERR_DUP;
-		if (parse_dq(&vps_p->res.dq.diskspace, val, 1))
+		if (parse_dq(&vps_p->res.dq.diskspace, val, 1024))
 			return ERR_INVAL;
 		break;
 	case PARAM_DISKINODES:
 		if (vps_p->res.dq.diskinodes != NULL)
 			return ERR_DUP;
-		if (parse_dq(&vps_p->res.dq.diskinodes, val, 0))
+		if (parse_dq(&vps_p->res.dq.diskinodes, val, 1))
 			return ERR_INVAL;
 		break;
 	case PARAM_QUOTATIME:
@@ -2226,6 +2222,9 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 	case PARAM_QUOTAUGIDLIMIT:
 		ret = conf_parse_ulong(&vps_p->res.dq.ugidlimit, val);
 		break;
+	case PARAM_OFFLINE_RESIZE:
+		vps_p->res.dq.offline_resize = YES;
+		break;
 	case PARAM_DEVICES:
 		ret = parse_dev(vps_p, val);
 		break;
@@ -2353,6 +2352,9 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 	case PARAM_SNAPSHOT_SKIP_CONFIG:
 		vps_p->snap.flags |= SNAPSHOT_SKIP_CONFIG;
 		break;
+	case PARAM_SNAPSHOT_SKIP_RESUME:
+		vps_p->snap.flags |= SNAPSHOT_SKIP_RESUME;
+		break;
 	case PARAM_SNAPSHOT_MOUNT_TARGET:
 		ret = conf_parse_str(&vps_p->snap.target, val);
 		break;
@@ -3079,6 +3081,7 @@ static void merge_env(env_param_t *dst, env_param_t *src)
 {
 	MERGE_INT(veid)
 	MERGE_INT(ipt_mask)
+	MERGE_INT(nf_mask)
 	MERGE_INT(features_mask)
 	MERGE_INT(features_known)
 }
