@@ -210,6 +210,8 @@ find:
 			ploop_mode = PLOOP_EXPANDED_MODE;
 		param.mode = ploop_mode;
 		param.size = dq->diskspace[1]; // limit
+		if (dq->diskinodes)
+			param.inodes = dq->diskinodes[1];
 		ret = vzctl_create_image(tmp_dir, &param);
 		if (ret)
 			goto err;
@@ -220,6 +222,7 @@ find:
 			goto err;
 		}
 		mount_param.target = fs->root;
+		mount_param.mount_data = fs->mount_opts;
 		ret = vzctl_mount_image(tmp_dir, &mount_param);
 		if (ret)
 			goto err;
@@ -394,6 +397,15 @@ int vps_create(vps_handler *h, envid_t veid, vps_param *vps_p, vps_param *cmd_p,
 		ret = VZ_FS_PRVT_AREA_EXIST;
 		goto err_cfg;
 	}
+
+	if (vps_p->opt.layout == 0) {
+#ifdef HAVE_PLOOP
+		vps_p->opt.layout = VE_LAYOUT_PLOOP;
+#else
+		vps_p->opt.layout = VE_LAYOUT_SIMFS;
+#endif
+	}
+
 	if (vps_p->opt.layout == VE_LAYOUT_PLOOP && !is_ploop_supported()) {
 		ret = VZ_PLOOP_UNSUP;
 		goto err_cfg;
