@@ -363,20 +363,19 @@ static void read_osrelease_conf(const char *dist, char *osrelease)
 #define KVER(a, b, c) (((a) << 16) + ((b) << 8) + (c))
 static int compare_osrelease(const char *cur, const char *min)
 {
-	int cur_a, cur_b, cur_c;
-	int min_a, min_b, min_c;
+	int cur_a, cur_b, cur_c = 0;
+	int min_a, min_b, min_c = 0;
 	int ret;
 
 	ret = sscanf(cur, "%d.%d.%d", &cur_a, &cur_b, &cur_c);
-	if (ret != 3) {
+	if (ret < 2) {
 		logger(-1, 0, "Unable to parse kernel osrelease (%s)", cur);
 		return -1;
 	}
 
 	ret = sscanf(min, "%d.%d.%d", &min_a, &min_b, &min_c);
-	if (ret != 3) {
-		logger(-1, 0, "Unable to parse value (%s) from "
-				OSRELEASE_CFG, min);
+	if (ret < 2) {
+		logger(-1, 0, "Unable to parse kernel osrelease (%s)", min);
 		return -1;
 	}
 
@@ -387,6 +386,26 @@ static int compare_osrelease(const char *cur, const char *min)
 }
 #undef KVER
 
+/* Checks if the current kernel version >= min_version
+ *
+ * Return value:
+ *	-1: error
+ *	 0: current kernel is sufficient
+ *	 1: current kernel is too old
+ */
+int check_min_kernel_version(const char *min_version)
+{
+	struct utsname uts;
+
+	/* Check if currrent kernel is equal or greater than min_version */
+	if (uname(&uts) != 0) {
+		logger(-1, errno, "Error in uname()");
+		return -1;
+	}
+
+	return compare_osrelease(uts.release, min_version);
+}
+
 /** Find out if a container needs setting osrelease,
   * and set it if needed. */
 static void get_osrelease(vps_res *res)
