@@ -64,16 +64,17 @@ static void usage(int rc)
 "\n"
 "vzctl create <ctid> [--ostemplate <name>] [--config <name>]\n"
 "   [--layout ploop|simfs] [--hostname <name>] [--name <name>] [--ipadd <addr>]\n"
-"   [--diskspace <kbytes>] [--private <path>] [--root <path>]\n"
+"   [--diskspace <kbytes>] [--diskinodes <NUM> [--private <path>] [--root <path>]\n"
 "   [--local_uid <UID>] [--local_gid <GID>]\n"
 "vzctl start <ctid> [--force] [--wait] [--skip-fsck]\n"
 "vzctl destroy | mount | umount | stop | restart | status <ctid>\n"
 #ifdef HAVE_PLOOP
-"vzctl convert <ctid> [--layout ploop[:mode]] [--diskspace <kbytes>]\n"
+"vzctl convert <ctid> [--layout ploop[:mode]]\n"
 "vzctl compact <ctid>\n"
 "vzctl snapshot <ctid> [--id <uuid>] [--name <name>] [--description <desc>]\n"
 "   [--skip-suspend]\n"
-"vzctl snapshot-switch | snapshot-delete <ctid> --id <uuid>\n"
+"vzctl snapshot-switch <ctid> --id <uuid> [--skip-resume] [--skip-config]\n"
+"vzctl snapshot-delete <ctid> --id <uuid>\n"
 "vzctl snapshot-mount <ctid> --id <uuid> --target <dir>\n"
 "vzctl snapshot-umount <ctid> --id <uuid>\n"
 "vzctl snapshot-list <ctid> [-H] [-o field[,field...]] [--id <uuid>]\n"
@@ -93,7 +94,7 @@ static void usage(int rc)
 "   [--cpuunits <N>] [--cpulimit <N>] [--cpus <N>] [--cpumask <cpus>]\n"
 "   [--diskspace <soft>[:<hard>]] [--diskinodes <soft>[:<hard>]]\n"
 "   [--quotatime <N>] [--quotaugidlimit <N>] [--mount_opts <opt>[,<opt>...]]\n"
-"   [--capability <name>:on|off ...]\n"
+"   [--offline-resize] [--capability <name>:on|off ...]\n"
 "   [--devices b|c:major:minor|all:r|w|rw]\n"
 "   [--devnodes device:r|w|rw|none]\n"
 "   [--netif_add <ifname[,mac,host_ifname,host_mac,bridge]]>]\n"
@@ -126,6 +127,28 @@ static void usage(int rc)
 	exit(rc);
 }
 
+/* Do various checks on global config,
+ * issue warnings and/or fix things.
+ */
+void validate_global_config(vps_param *gparam) {
+	if (gparam->res.env.nf_mask) {
+		logger(0, 0, "Warning: NETFILTER should not be set in "
+				GLOBAL_CFG ", ignoring");
+		logger(0, 0, "Please remove NETFILTER from " GLOBAL_CFG
+				"to get rid of this warning");
+		gparam->res.env.nf_mask = 0;
+	}
+#if 0	/* TODO: enable past vzctl 4.7 */
+	if (gparam->res.env.ipt_mask) {
+		/* TODO: ignore global iptables in vzctl 4.8? */
+		logger(0, 0, "Warning: please don't use IPTABLES in "
+				GLOBAL_CFG ", it is obsoleted by "
+				"per-CT netfilter option and will be "
+				"ignored in a future version");
+	}
+#endif
+}
+
 int main(int argc, char *argv[], char *envp[])
 {
 	act_t action = -1;
@@ -212,7 +235,9 @@ int main(int argc, char *argv[], char *envp[])
 #endif
 	} else if (!strcmp(argv[1], "status")) {
 		action = ACTION_STATUS;
-		quiet = 1;
+		verbose = -1;
+		verbose_custom = 1;
+		set_log_verbose(verbose); /* only stderr messages */
 	} else if (!strcmp(argv[1], "suspend") || !strcmp(argv[1], "chkpnt")) {
 		action = ACTION_SUSPEND;
 	} else if (!strcmp(argv[1], "resume") || !strcmp(argv[1], "restore")) {
@@ -232,6 +257,9 @@ int main(int argc, char *argv[], char *envp[])
 		action = ACTION_SNAPSHOT_DELETE;
 	} else if (!strcmp(argv[1], "snapshot-list")) {
 		action = ACTION_SNAPSHOT_LIST;
+		verbose = -1;
+		verbose_custom = 1;
+		set_log_verbose(verbose); /* only stderr messages */
 	} else if (!strcmp(argv[1], "snapshot-mount")) {
 		action = ACTION_SNAPSHOT_MOUNT;
 	} else if (!strcmp(argv[1], "snapshot-umount")) {
@@ -290,6 +318,8 @@ int main(int argc, char *argv[], char *envp[])
 	{
 		goto error;
 	}
+	validate_global_config(gparam);
+
 	if (veid == 0 && action != ACTION_SET) {
 		fprintf(stderr, "Only set actions are allowed for CT0\n");
 		ret = VZ_INVALID_PARAMETER_VALUE;
